flutter_multi_scroll_table library

Classes

EachCell
A widget that represents a single cell in a table. It can be used for both header and data cells with various customization options.
FlutterMultiScrollTable
A widget that represents a multi-scrollable table with resizable columns.
ResizeableColumn

Extensions

EachCellCopyWith on EachCell