jsonDataList property

List<Map<String, dynamic>>? jsonDataList
final

A list of maps where each map represents a row of data in JSON format. Each key in the map corresponds to a column header, and the value is the cell data. This is used to generate column data and headers if not explicitly provided.

Implementation

final List<Map<String, dynamic>>? jsonDataList;